@@ -98,9 +98,9 @@ class AutoscalingClient(AbstractClient):
 
 
     def CompleteLifecycleAction(self, request):
-        """This API (CompleteLifecycleAction) is used to complete a lifecycle action.
+        """This API is used to complete a lifecycle action by setting the status of lifecycle hook to `CONTINUE` or `ABANDON`.
 
-        * The result ("CONTINUE" or "ABANDON") of a specific lifecycle hook can be specified by calling this API. If this API is not called at all, the lifecycle hook will be processed based on the "DefaultResult" after timeout.
+        * If this API is not called, the lifecycle hook goes to the status specified in `DefaultResult` after the timeout period.
 
         :param request: Request instance for CompleteLifecycleAction.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.CompleteLifecycleActionRequest`
@@ -173,9 +173,9 @@ class AutoscalingClient(AbstractClient):
     def CreateLaunchConfiguration(self, request):
         """This API is used to create a launch configuration.
 
-        * To modify a launch configuration, you can use `ModifyLaunchConfigurationAttributes`.
+        * To modify a launch configuration, please use `ModifyLaunchConfigurationAttributes`.
 
-        * You can create up to 20 launch configurations for each project. For more information, see [Usage Limits](https://intl.cloud.tencent.com/document/product/377/3120?from_cn_redirect=1).
+        * Up to 20 launch configurations can be created for each project. For more information, see [Usage Limits](https://intl.cloud.tencent.com/document/product/377/3120?from_cn_redirect=1).
 
         :param request: Request instance for CreateLaunchConfiguration.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.CreateLaunchConfigurationRequest`
@@ -856,10 +856,11 @@ class AutoscalingClient(AbstractClient):
 
 
     def ExecuteScalingPolicy(self, request):
-        """This API (ExecuteScalingPolicy) is used to execute a scaling policy.
+        """This API is used to execute a scaling policy.
 
         * The scaling policy can be executed based on the scaling policy ID.
-        * When the auto scaling group to which the scaling policy belongs is performing a scaling activity, the scaling policy will be rejected.
+        * The policy cannot be executed if there are ongoing scaling actions on the scaling group.
+        * Executing a target tracking policy is not supported.
 
         :param request: Request instance for ExecuteScalingPolicy.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.ExecuteScalingPolicyRequest`
