@@ -206,6 +206,9 @@ INVALIDPARAMETER_PARAMSMISSING = 'InvalidParameter.ParamsMissing'
 # The user UIN is invalid.
 INVALIDPARAMETER_QCLOUDUININVALID = 'InvalidParameter.QcloudUinInvalid'
 
+# 
+INVALIDPARAMETER_QUHUITXTNOTMATCH = 'InvalidParameter.QuhuiTxtNotMatch'
+
 # The TXT record was not set or has not taken effect. Try again later.
 INVALIDPARAMETER_QUHUITXTRECORDWAIT = 'InvalidParameter.QuhuiTxtRecordWait'
 
