@@ -607,78 +607,24 @@ class DescribeApplicationDataResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class DescribeScanResult(AbstractModel):
-    """Returned voice detection result
+class DescribeRecordInfoRequest(AbstractModel):
+    """DescribeRecordInfo request structure.
 
     """
 
     def __init__(self):
         r"""
-        :param Code: Business return code
-        :type Code: int
-        :param DataId: Unique data ID
-        :type DataId: str
-        :param ScanFinishTime: Detection completion timestamp
-        :type ScanFinishTime: int
-        :param HitFlag: Whether non-compliant information is detected
-        :type HitFlag: bool
-        :param Live: Whether it is a stream
-        :type Live: bool
-        :param Msg: Business return description
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type Msg: str
-        :param ScanPiece: Detection result, which will be returned if `Code` is 0
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type ScanPiece: list of ScanPiece
-        :param ScanStartTime: Detection task submission timestamp
-        :type ScanStartTime: int
-        :param Scenes: Voice detection scenario, which corresponds to the `Scene` at the time of request
-        :type Scenes: list of str
-        :param TaskId: Voice detection task ID, which is assigned by the backend
-        :type TaskId: str
-        :param Url: File or stream address
-        :type Url: str
-        :param Status: Detection task execution result status. Valid values:
-<li>Start: Task started</li>
-<li>Success: Task ended successfully</li>
-<li>Error: An exception occurs</li>
-        :type Status: str
-        :param BizId: ID of the application submitted for detection
+        :param TaskId: ID of the ongoing task, which is returned from the `StartRecord` API.
+        :type TaskId: int
+        :param BizId: Application ID.
         :type BizId: int
         """
-        self.Code = None
-        self.DataId = None
-        self.ScanFinishTime = None
-        self.HitFlag = None
-        self.Live = None
-        self.Msg = None
-        self.ScanPiece = None
-        self.ScanStartTime = None
-        self.Scenes = None
         self.TaskId = None
-        self.Url = None
-        self.Status = None
         self.BizId = None
 
 
     def _deserialize(self, params):
-        self.Code = params.get("Code")
-        self.DataId = params.get("DataId")
-        self.ScanFinishTime = params.get("ScanFinishTime")
-        self.HitFlag = params.get("HitFlag")
-        self.Live = params.get("Live")
-        self.Msg = params.get("Msg")
-        if params.get("ScanPiece") is not None:
-            self.ScanPiece = []
-            for item in params.get("ScanPiece"):
-                obj = ScanPiece()
-                obj._deserialize(item)
-                self.ScanPiece.append(obj)
-        self.ScanStartTime = params.get("ScanStartTime")
-        self.Scenes = params.get("Scenes")
         self.TaskId = params.get("TaskId")
-        self.Url = params.get("Url")
-        self.Status = params.get("Status")
         self.BizId = params.get("BizId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
@@ -689,62 +635,100 @@ Note: This field may return `null`, indicating that no valid values can be obtai
         
 
 
-class DescribeScanResultListRequest(AbstractModel):
-    """DescribeScanResultList request structure.
+class DescribeRecordInfoResponse(AbstractModel):
+    """DescribeRecordInfo response structure.
 
     """
 
     def __init__(self):
         r"""
-        :param BizId: Application ID, which is obtained when you create an application in the [GME console](https://console.cloud.tencent.com/gamegme).
-        :type BizId: int
-        :param TaskIdList: List of IDs of the tasks to be queried. Up to 100 entries can be added in the ID list.
-        :type TaskIdList: list of str
-        :param Limit: Number of task results to be returned. Default value: 10. Maximum value: 500. This parameter will be ignored for large file tasks where all results will be returned.
-        :type Limit: int
-        """
-        self.BizId = None
-        self.TaskIdList = None
-        self.Limit = None
-
-
-    def _deserialize(self, params):
-        self.BizId = params.get("BizId")
-        self.TaskIdList = params.get("TaskIdList")
-        self.Limit = params.get("Limit")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class DescribeScanResultListResponse(AbstractModel):
-    """DescribeScanResultList response structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param Data: Result of the voice detection task to be queried
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type Data: list of DescribeScanResult
+        :param RecordInfo: Information about the recording task.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :type RecordInfo: list of RecordInfo
+        :param RecordMode: Recording mode. Valid values: `1`: single stream; `2`: mixed streams; `3`: single stream and mixed streams.
+        :type RecordMode: int
+        :param RoomId: Room ID.
+        :type RoomId: str
         :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
         :type RequestId: str
         """
-        self.Data = None
+        self.RecordInfo = None
+        self.RecordMode = None
+        self.RoomId = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
-        if params.get("Data") is not None:
-            self.Data = []
-            for item in params.get("Data"):
-                obj = DescribeScanResult()
+        if params.get("RecordInfo") is not None:
+            self.RecordInfo = []
+            for item in params.get("RecordInfo"):
+                obj = RecordInfo()
                 obj._deserialize(item)
-                self.Data.append(obj)
+                self.RecordInfo.append(obj)
+        self.RecordMode = params.get("RecordMode")
+        self.RoomId = params.get("RoomId")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeTaskInfoRequest(AbstractModel):
+    """DescribeTaskInfo request structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param BizId: Application ID.
+        :type BizId: int
+        :param RoomId: Room ID.
+        :type RoomId: str
+        """
+        self.BizId = None
+        self.RoomId = None
+
+
+    def _deserialize(self, params):
+        self.BizId = params.get("BizId")
+        self.RoomId = params.get("RoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeTaskInfoResponse(AbstractModel):
+    """DescribeTaskInfo response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: ID of the ongoing task, which is returned from the `StartRecord` API.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :type TaskId: int
+        :param RecordMode: Recording mode. Valid values: `1`: single stream; `2`: mixed streams; `3`: single stream and mixed streams.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :type RecordMode: int
+        :param SubscribeRecordUserIds: Allowlist or blocklist for stream subscription.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :type SubscribeRecordUserIds: :class:`tencentcloud.gme.v20180711.models.SubscribeRecordUserIds`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.TaskId = None
+        self.RecordMode = None
+        self.SubscribeRecordUserIds = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        self.RecordMode = params.get("RecordMode")
+        if params.get("SubscribeRecordUserIds") is not None:
+            self.SubscribeRecordUserIds = SubscribeRecordUserIds()
+            self.SubscribeRecordUserIds._deserialize(params.get("SubscribeRecordUserIds"))
         self.RequestId = params.get("RequestId")
 
 
@@ -827,6 +811,61 @@ class ModifyAppStatusResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ModifyRecordInfoRequest(AbstractModel):
+    """ModifyRecordInfo request structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: ID of the ongoing task, which is returned from the `StartRecord` API.
+        :type TaskId: int
+        :param RecordMode: Recording mode. Valid values: `1`: single stream; `2`: mixed streams; `3`: single stream and mixed streams.
+        :type RecordMode: int
+        :param BizId: Application ID.
+        :type BizId: int
+        :param SubscribeRecordUserIds: Allowlist or blocklist for stream subscription.
+        :type SubscribeRecordUserIds: :class:`tencentcloud.gme.v20180711.models.SubscribeRecordUserIds`
+        """
+        self.TaskId = None
+        self.RecordMode = None
+        self.BizId = None
+        self.SubscribeRecordUserIds = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        self.RecordMode = params.get("RecordMode")
+        self.BizId = params.get("BizId")
+        if params.get("SubscribeRecordUserIds") is not None:
+            self.SubscribeRecordUserIds = SubscribeRecordUserIds()
+            self.SubscribeRecordUserIds._deserialize(params.get("SubscribeRecordUserIds"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyRecordInfoResponse(AbstractModel):
+    """ModifyRecordInfo response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class OverseaTextStatisticsItem(AbstractModel):
     """Usage statistics of Voice-to-Text of outside-MLC requests
 
@@ -949,37 +988,34 @@ Note: This field may return `null`, indicating that no valid values can be obtai
         
 
 
-class ScanDetail(AbstractModel):
-    """Voice detection details
+class RecordInfo(AbstractModel):
+    """Information about the recording task in a room.
+    Note: This field may return null, indicating that no valid values can be obtained.
 
     """
 
     def __init__(self):
         r"""
-        :param Label: Violation scenario. For more information, please see the definition of <a href="https://intl.cloud.tencent.com/document/product/607/37622?from_cn_redirect=1#Label_Value">Label</a>.
-        :type Label: str
-        :param Rate: Confidence score in scenario. Value range: [0.00,100.00]. The higher the score, the more likely the content is non-compliant.
-        :type Rate: str
-        :param KeyWord: Non-compliant keyword
-        :type KeyWord: str
-        :param StartTime: Start time offset of keyword from 0 in audio (in milliseconds)
-        :type StartTime: int
-        :param EndTime: End time offset of keyword from 0 in audio (in milliseconds)
-        :type EndTime: int
+        :param UserId: User ID. The value is `0` in mixed streams recording mode.
+        :type UserId: str
+        :param FileName: Recording filename.
+        :type FileName: str
+        :param RecordBeginTime: Recording start time, which is a Unix timestamp. Example: 1234567868.
+        :type RecordBeginTime: int
+        :param RecordStatus: Recording status. Valid values: `2`: recording; `10`: to be transcoded; `11`: transcoding; `12`: uploading; `13`: uploaded; `14`: user notified.
+        :type RecordStatus: int
         """
-        self.Label = None
-        self.Rate = None
-        self.KeyWord = None
-        self.StartTime = None
-        self.EndTime = None
+        self.UserId = None
+        self.FileName = None
+        self.RecordBeginTime = None
+        self.RecordStatus = None
 
 
     def _deserialize(self, params):
-        self.Label = params.get("Label")
-        self.Rate = params.get("Rate")
-        self.KeyWord = params.get("KeyWord")
-        self.StartTime = params.get("StartTime")
-        self.EndTime = params.get("EndTime")
+        self.UserId = params.get("UserId")
+        self.FileName = params.get("FileName")
+        self.RecordBeginTime = params.get("RecordBeginTime")
+        self.RecordStatus = params.get("RecordStatus")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -989,121 +1025,35 @@ class ScanDetail(AbstractModel):
         
 
 
-class ScanPiece(AbstractModel):
-    """Voice detection result, which will be returned if `Code` is 0.
+class StartRecordRequest(AbstractModel):
+    """StartRecord request structure.
 
     """
 
     def __init__(self):
         r"""
-        :param DumpUrl: Audio retention address, which will be returned for stream detection. The audio will be retained for 30 minutes.
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type DumpUrl: str
-        :param HitFlag: Whether non-compliant information is detected
-        :type HitFlag: bool
-        :param MainType: Main non-compliant content type
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type MainType: str
-        :param ScanDetail: Voice detection details
-        :type ScanDetail: list of ScanDetail
-        :param RoomId: GME Voice Chat room ID, which is the `RoomId` passed through when the task was submitted.
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type RoomId: str
-        :param OpenId: GME Voice Chat user ID, which is the `OpenId` passed through when the task was submitted.
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type OpenId: str
-        :param Info: Remarks
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type Info: str
-        :param Offset: Offset time of multipart in stream during stream detection (in milliseconds)
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type Offset: int
-        :param Duration: Multipart duration during stream detection
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type Duration: int
-        :param PieceStartTime: Multipart detection start time
-Note: This field may return `null`, indicating that no valid values can be obtained.
-        :type PieceStartTime: int
-        """
-        self.DumpUrl = None
-        self.HitFlag = None
-        self.MainType = None
-        self.ScanDetail = None
-        self.RoomId = None
-        self.OpenId = None
-        self.Info = None
-        self.Offset = None
-        self.Duration = None
-        self.PieceStartTime = None
-
-
-    def _deserialize(self, params):
-        self.DumpUrl = params.get("DumpUrl")
-        self.HitFlag = params.get("HitFlag")
-        self.MainType = params.get("MainType")
-        if params.get("ScanDetail") is not None:
-            self.ScanDetail = []
-            for item in params.get("ScanDetail"):
-                obj = ScanDetail()
-                obj._deserialize(item)
-                self.ScanDetail.append(obj)
-        self.RoomId = params.get("RoomId")
-        self.OpenId = params.get("OpenId")
-        self.Info = params.get("Info")
-        self.Offset = params.get("Offset")
-        self.Duration = params.get("Duration")
-        self.PieceStartTime = params.get("PieceStartTime")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class ScanVoiceRequest(AbstractModel):
-    """ScanVoice request structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param BizId: Application ID, which is obtained when you create an application in the [GME console - Service Management](https://console.cloud.tencent.com/gamegme).
+        :param BizId: Application ID.
         :type BizId: int
-        :param Scenes: Voice detection scenario. It must be `default`. See the <a href="#Label_Value">Label description</a> as the result.
-        :type Scenes: list of str
-        :param Live: Whether it is a live stream. Values: `false` (voice file), `true` (live stream).
-        :type Live: bool
-        :param Tasks: Voice detection task list. Up to 100 tasks can be added in the list. 
-<li>`DataId`: Unique data ID</li>
-<li>`Url`: URL-encoded data file URL, which is a pull address if the detected voice is a stream</li>
-        :type Tasks: list of Task
-        :param Callback: Async callback address for detection result. For more information, please see the <a href="#Callback_Declare">Callback description</a> above. (Note: If this field is empty, the detection result can only be queried by calling the `DescribeScanResultList` API.)
-        :type Callback: str
-        :param Lang: Language. Chinese will be used if it is left empty.
-        :type Lang: str
+        :param RoomId: Room ID.
+        :type RoomId: str
+        :param RecordMode: Recording mode. Valid values: `1`: single stream; `2`: mixed streams; `3`: single stream and mixed streams.
+        :type RecordMode: int
+        :param SubscribeRecordUserIds: Allowlist or blocklist for stream subscription. If you do not specify this parameter, the audio streams of all the users in the room are subscribed to by default.
+        :type SubscribeRecordUserIds: :class:`tencentcloud.gme.v20180711.models.SubscribeRecordUserIds`
         """
         self.BizId = None
-        self.Scenes = None
-        self.Live = None
-        self.Tasks = None
-        self.Callback = None
-        self.Lang = None
+        self.RoomId = None
+        self.RecordMode = None
+        self.SubscribeRecordUserIds = None
 
 
     def _deserialize(self, params):
         self.BizId = params.get("BizId")
-        self.Scenes = params.get("Scenes")
-        self.Live = params.get("Live")
-        if params.get("Tasks") is not None:
-            self.Tasks = []
-            for item in params.get("Tasks"):
-                obj = Task()
-                obj._deserialize(item)
-                self.Tasks.append(obj)
-        self.Callback = params.get("Callback")
-        self.Lang = params.get("Lang")
+        self.RoomId = params.get("RoomId")
+        self.RecordMode = params.get("RecordMode")
+        if params.get("SubscribeRecordUserIds") is not None:
+            self.SubscribeRecordUserIds = SubscribeRecordUserIds()
+            self.SubscribeRecordUserIds._deserialize(params.get("SubscribeRecordUserIds"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1113,59 +1063,25 @@ class ScanVoiceRequest(AbstractModel):
         
 
 
-class ScanVoiceResponse(AbstractModel):
-    """ScanVoice response structure.
+class StartRecordResponse(AbstractModel):
+    """StartRecord response structure.
 
     """
 
     def __init__(self):
         r"""
-        :param Data: Voice moderation result. <li>`DataId`: Corresponding `DataId` in request.</li>
-<li>`TaskID`: Moderation task ID, which is used to poll the voice detection result.</li>
-        :type Data: list of ScanVoiceResult
+        :param TaskId: Task ID.
+        :type TaskId: int
         :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
         :type RequestId: str
         """
-        self.Data = None
+        self.TaskId = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
-        if params.get("Data") is not None:
-            self.Data = []
-            for item in params.get("Data"):
-                obj = ScanVoiceResult()
-                obj._deserialize(item)
-                self.Data.append(obj)
-        self.RequestId = params.get("RequestId")
-
-
-class ScanVoiceResult(AbstractModel):
-    """Result of voice moderation
-
-    """
-
-    def __init__(self):
-        r"""
-        :param DataId: Data ID
-        :type DataId: str
-        :param TaskId: Task ID
-        :type TaskId: str
-        """
-        self.DataId = None
-        self.TaskId = None
-
-
-    def _deserialize(self, params):
-        self.DataId = params.get("DataId")
         self.TaskId = params.get("TaskId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
+        self.RequestId = params.get("RequestId")
 
 
 class StatisticsItem(AbstractModel):
@@ -1196,6 +1112,51 @@ class StatisticsItem(AbstractModel):
         
 
 
+class StopRecordRequest(AbstractModel):
+    """StopRecord request structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: Task ID.
+        :type TaskId: int
+        :param BizId: Application ID.
+        :type BizId: int
+        """
+        self.TaskId = None
+        self.BizId = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        self.BizId = params.get("BizId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class StopRecordResponse(AbstractModel):
+    """StopRecord response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class StreamTextStatisticsItem(AbstractModel):
     """Stream-to-Text usage statistics
 
@@ -1221,6 +1182,36 @@ Note: This field may return `null`, indicating that no valid values can be obtai
         
 
 
+class SubscribeRecordUserIds(AbstractModel):
+    """Allowlist or blocklist for stream subscription.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param UnSubscribeUserIds: Blocklist for audio subscription. For example, `["1", "2", "3"]` means to not subscribe to the audio streams of users 1, 2, and 3. If this parameter is left empty, the audio streams of all users (max 20) in the room will not be subscribed to.
+Note: You cannot specify `UnSubscribeAudioUserIds` and `SubscribeAudioUserIds` at the same time.
+        :type UnSubscribeUserIds: list of str
+        :param SubscribeUserIds: Allowlist for audio subscription. For example, `["1", "2", "3"]` means to subscribe to the audio streams of users 1, 2, and 3. If this parameter is left empty, the audio streams of all users (max 20) in the room will be subscribed to.
+Note: You cannot specify `UnSubscribeAudioUserIds` and `SubscribeAudioUserIds` at the same time.
+        :type SubscribeUserIds: list of str
+        """
+        self.UnSubscribeUserIds = None
+        self.SubscribeUserIds = None
+
+
+    def _deserialize(self, params):
+        self.UnSubscribeUserIds = params.get("UnSubscribeUserIds")
+        self.SubscribeUserIds = params.get("SubscribeUserIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Tag(AbstractModel):
     """Tag list
 
@@ -1251,42 +1242,6 @@ Note: This field may return `null`, indicating that no valid values can be obtai
         
 
 
-class Task(AbstractModel):
-    """Voice detection task list
-
-    """
-
-    def __init__(self):
-        r"""
-        :param DataId: Unique data ID
-        :type DataId: str
-        :param Url: URL-encoded data file URL, which is a pull address if the detected voice is a stream.
-        :type Url: str
-        :param RoomId: GME Voice Chat room ID, which is entered during voice analysis by GME Voice Chat.
-        :type RoomId: str
-        :param OpenId: GME Voice Chat user ID, which is entered during voice analysis by GME Voice Chat.
-        :type OpenId: str
-        """
-        self.DataId = None
-        self.Url = None
-        self.RoomId = None
-        self.OpenId = None
-
-
-    def _deserialize(self, params):
-        self.DataId = params.get("DataId")
-        self.Url = params.get("Url")
-        self.RoomId = params.get("RoomId")
-        self.OpenId = params.get("OpenId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
 class VoiceFilterConf(AbstractModel):
     """Configuration information of Phrase Filtering
 
