@@ -125,6 +125,9 @@ FAILEDOPERATION_DIVISIONBYZERO = 'FailedOperation.DivisionByZero'
 # Backend service timed out.
 FAILEDOPERATION_DOHTTPTRANSFERFAILED = 'FailedOperation.DoHTTPTransferFailed'
 
+# DoTRPCTransferFailed
+FAILEDOPERATION_DOTRPCTRANSFERFAILED = 'FailedOperation.DoTRPCTransferFailed'
+
 # Failed to query analysis data.
 FAILEDOPERATION_DRUIDQUERYFAILED = 'FailedOperation.DruidQueryFailed'
 
