@@ -210,6 +210,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CloneInstances(self, request):
+        """This API is used to clone a complete new instance based on the current instance backup file.
+
+        :param request: Request instance for CloneInstances.
+        :type request: :class:`tencentcloud.redis.v20180412.models.CloneInstancesRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.CloneInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CloneInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.CloneInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CloseSSL(self, request):
         """This API is used to disable SSL.
 
@@ -257,7 +280,7 @@ class RedisClient(AbstractClient):
 
 
     def CreateInstances(self, request):
-        """This API is used to create a Redis instance.
+        """This API is used to create an TencentDB or Redis instance.
 
         :param request: Request instance for CreateInstances.
         :type request: :class:`tencentcloud.redis.v20180412.models.CreateInstancesRequest`
@@ -417,6 +440,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeBandwidthRange(self, request):
+        """This API is used to query the information of instance bandwidth.
+
+        :param request: Request instance for DescribeBandwidthRange.
+        :type request: :class:`tencentcloud.redis.v20180412.models.DescribeBandwidthRangeRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.DescribeBandwidthRangeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBandwidthRange", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBandwidthRangeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeCommonDBInstances(self, request):
         """This API has been disused. It was used to query the list of Redis instance information.
 
@@ -924,7 +970,7 @@ class RedisClient(AbstractClient):
 
 
     def DescribeParamTemplateInfo(self, request):
-        """This API is used to query the parameter template details.
+        """This API is used to query the details of a parameter template.
 
         :param request: Request instance for DescribeParamTemplateInfo.
         :type request: :class:`tencentcloud.redis.v20180412.models.DescribeParamTemplateInfoRequest`
@@ -1085,7 +1131,7 @@ class RedisClient(AbstractClient):
 
 
     def DescribeSSLStatus(self, request):
-        """This API is used to query SSL status.
+        """This API is used to query the SSL authentication information of an instance, such as enablement status, configuration status, and certificate address.
 
         :param request: Request instance for DescribeSSLStatus.
         :type request: :class:`tencentcloud.redis.v20180412.models.DescribeSSLStatusRequest`
@@ -1407,7 +1453,7 @@ class RedisClient(AbstractClient):
 
 
     def ModfiyInstancePassword(self, request):
-        """This API is used to change the Redis password.
+        """This API is used to modify the access password for an instance.
 
         :param request: Request instance for ModfiyInstancePassword.
         :type request: :class:`tencentcloud.redis.v20180412.models.ModfiyInstancePasswordRequest`
@@ -1705,6 +1751,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RemoveReplicationInstance(self, request):
+        """This API is used to remove a member from a replication group.
+
+        :param request: Request instance for RemoveReplicationInstance.
+        :type request: :class:`tencentcloud.redis.v20180412.models.RemoveReplicationInstanceRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.RemoveReplicationInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RemoveReplicationInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.RemoveReplicationInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RenewInstance(self, request):
         """This API is used to renew an instance.
 
