@@ -266,6 +266,9 @@ INTERNALERROR_KUBERNETESINTERNAL = 'InternalError.KubernetesInternal'
 # Failed to obtain the kubernetes resource list.
 INTERNALERROR_KUBERNETESLISTOPERATIONERROR = 'InternalError.KubernetesListOperationError'
 
+# Kubernetes Patch operation failed.
+INTERNALERROR_KUBERNETESPATCHOPERATIONERROR = 'InternalError.KubernetesPatchOperationError'
+
 # An error occurs while calling the underlying CLB
 INTERNALERROR_LBCOMMON = 'InternalError.LbCommon'
 
