@@ -32,6 +32,9 @@ FAILEDOPERATION_CLASSNOFOUND = 'FailedOperation.ClassNoFound'
 # Operation failed: unsupported cover type.
 FAILEDOPERATION_COVERTYPE = 'FailedOperation.CoverType'
 
+# 
+FAILEDOPERATION_DBERROR = 'FailedOperation.DBError'
+
 # You cannot modify the settings of the domain name as it is being deployed.
 FAILEDOPERATION_DOMAINDEPLOYING = 'FailedOperation.DomainDeploying'
 
